
/*  A Bison parser, made from cfg-grammar.y
 by  GNU Bison version 1.27
  */

#define YYBISON 1  /* Identify Bison output.  */

#define	KW_SOURCE	257
#define	KW_DESTINATION	258
#define	KW_LOG	259
#define	KW_OPTIONS	260
#define	KW_FILTER	261
#define	KW_INTERNAL	262
#define	KW_FILE	263
#define	KW_UNIX_STREAM	264
#define	KW_UNIX_DGRAM	265
#define	KW_UDP	266
#define	KW_TCP	267
#define	KW_USER	268
#define	KW_DOOR	269
#define	KW_SUN_STREAMS	270
#define	KW_MARK_FREQ	271
#define	KW_SYNC_FREQ	272
#define	KW_LONG_HOSTNAMES	273
#define	KW_LOG_FIFO_SIZE	274
#define	KW_TIME_REOPEN	275
#define	KW_OWNER	276
#define	KW_GROUP	277
#define	KW_PERM	278
#define	KW_LOCALIP	279
#define	KW_IP	280
#define	KW_LOCALPORT	281
#define	KW_PORT	282
#define	KW_DESTPORT	283
#define	KW_COMPRESS	284
#define	KW_MAC	285
#define	KW_AUTH	286
#define	KW_ENCRYPT	287
#define	KW_FACILITY	288
#define	KW_LEVEL	289
#define	KW_PROGRAM	290
#define	KW_HOST	291
#define	KW_MATCH	292
#define	KW_YES	293
#define	KW_NO	294
#define	KW_REQUIRED	295
#define	KW_ALLOW	296
#define	KW_DENY	297
#define	DOTDOT	298
#define	IDENTIFIER	299
#define	NUMBER	300
#define	STRING	301
#define	KW_OR	302
#define	KW_AND	303
#define	KW_NOT	304

#line 25 "cfg-grammar.y"


#include "cfgfile.h"
#include "filters.h"
#include "syslog-names.h"
#include "format.h"
#include "afinter.h"
#include "affile.h"
#include "afsocket.h"
#include "afuser.h"
#include "afstreams.h"

#include <netinet/in.h>

void yyerror(char *msg);
int yylex();

struct log_source_driver *last_source_driver;
struct log_dest_driver *last_dest_driver;


#line 47 "cfg-grammar.y"
typedef union {
	UINT32 num;
	char *cptr;
	void *ptr;
	struct filter_expr_node *node;
} YYSTYPE;
#include <stdio.h>

#ifndef __cplusplus
#ifndef __STDC__
#define const
#endif
#endif



#define	YYFINAL		314
#define	YYFLAG		-32768
#define	YYNTBASE	57

#define YYTRANSLATE(x) ((unsigned)(x) <= 304 ? yytranslate[x] : 121)

static const char yytranslate[] = {     0,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,    54,
    55,     2,     2,    56,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,    51,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,    52,     2,    53,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
     2,     2,     2,     2,     2,     1,     3,     4,     5,     6,
     7,     8,     9,    10,    11,    12,    13,    14,    15,    16,
    17,    18,    19,    20,    21,    22,    23,    24,    25,    26,
    27,    28,    29,    30,    31,    32,    33,    34,    35,    36,
    37,    38,    39,    40,    41,    42,    43,    44,    45,    46,
    47,    48,    49,    50
};

#if YYDEBUG != 0
static const short yyprhs[] = {     0,
     0,     2,     6,     7,    10,    13,    16,    19,    22,    27,
    32,    36,    40,    44,    45,    47,    49,    51,    53,    57,
    62,    67,    72,    77,    82,    83,    87,    88,    92,    95,
    96,   101,   106,   111,   112,   115,   118,   119,   124,   129,
   134,   139,   140,   143,   146,   147,   149,   154,   159,   164,
   169,   170,   174,   177,   178,   183,   187,   188,   190,   192,
   194,   199,   204,   205,   209,   212,   213,   215,   220,   225,
   230,   235,   240,   245,   250,   252,   254,   255,   259,   261,
   266,   271,   276,   281,   282,   286,   289,   290,   292,   297,
   302,   307,   312,   316,   317,   322,   327,   332,   336,   337,
   342,   347,   352,   357,   362,   368,   370,   373,   377,   381,
   385,   390,   395,   400,   405,   410,   414,   416,   418,   422,
   424,   426,   430,   432,   434,   436,   438,   440,   442,   444
};

static const short yyrhs[] = {    58,
     0,    59,    51,    58,     0,     0,     3,    60,     0,     4,
    61,     0,     5,    62,     0,     7,   111,     0,     6,    63,
     0,   120,    52,    64,    53,     0,   120,    52,    88,    53,
     0,    52,   107,    53,     0,    52,   109,    53,     0,    65,
    51,    64,     0,     0,    66,     0,    67,     0,    68,     0,
    83,     0,     8,    54,    55,     0,     9,    54,   120,    55,
     0,    11,    54,    69,    55,     0,    10,    54,    71,    55,
     0,    12,    54,    75,    55,     0,    13,    54,    79,    55,
     0,     0,   120,    70,    73,     0,     0,   120,    72,    73,
     0,    74,    73,     0,     0,    22,    54,   120,    55,     0,
    23,    54,   120,    55,     0,    24,    54,    46,    55,     0,
     0,    76,    77,     0,    78,    77,     0,     0,    25,    54,
   120,    55,     0,    26,    54,   120,    55,     0,    27,    54,
    46,    55,     0,    28,    54,    46,    55,     0,     0,    80,
    81,     0,    82,    81,     0,     0,    78,     0,    32,    54,
   119,    55,     0,    31,    54,   119,    55,     0,    33,    54,
   119,    55,     0,    16,    54,    84,    55,     0,     0,   120,
    85,    86,     0,    87,    86,     0,     0,    15,    54,   120,
    55,     0,    89,    51,    88,     0,     0,    91,     0,    96,
     0,   106,     0,    20,    54,    46,    55,     0,     9,    54,
    92,    55,     0,     0,   120,    93,    94,     0,    95,    94,
     0,     0,    90,     0,    18,    54,    46,    55,     0,    30,
    54,   118,    55,     0,    33,    54,   118,    55,     0,    11,
    54,    97,    55,     0,    10,    54,    98,    55,     0,    12,
    54,    99,    55,     0,    13,    54,   102,    55,     0,   120,
     0,   120,     0,     0,   120,   100,   101,     0,    90,     0,
    25,    54,   120,    55,     0,    27,    54,    46,    55,     0,
    28,    54,    46,    55,     0,    29,    54,    46,    55,     0,
     0,   120,   103,   104,     0,   105,   104,     0,     0,   101,
     0,    31,    54,   118,    55,     0,    32,    54,   118,    55,
     0,    33,    54,   118,    55,     0,    14,    54,   120,    55,
     0,   108,    51,   107,     0,     0,     3,    54,   120,    55,
     0,     7,    54,   120,    55,     0,     4,    54,   120,    55,
     0,   110,    51,   109,     0,     0,    17,    54,    46,    55,
     0,    18,    54,    46,    55,     0,    19,    54,   118,    55,
     0,    21,    54,    46,    55,     0,    20,    54,    46,    55,
     0,   120,    52,   112,    51,    53,     0,   113,     0,    50,
   112,     0,   112,    48,   112,     0,   112,    49,   112,     0,
    54,   112,    55,     0,    34,    54,   114,    55,     0,    35,
    54,   116,    55,     0,    36,    54,   120,    55,     0,    37,
    54,   120,    55,     0,    38,    54,   120,    55,     0,   115,
    56,   114,     0,   115,     0,    45,     0,   117,    56,   116,
     0,   117,     0,    45,     0,    45,    44,    45,     0,    39,
     0,    40,     0,    46,     0,    41,     0,    42,     0,    43,
     0,    45,     0,    47,     0
};

#endif

#if YYDEBUG != 0
static const short yyrline[] = { 0,
   136,   140,   141,   145,   146,   147,   148,   149,   153,   157,
   161,   165,   169,   170,   174,   175,   176,   177,   181,   185,
   189,   190,   191,   192,   196,   203,   207,   214,   219,   220,
   224,   225,   226,   230,   236,   240,   241,   245,   246,   247,
   248,   253,   259,   263,   264,   268,   269,   270,   271,   275,
   279,   284,   288,   289,   293,   297,   298,   302,   303,   304,
   308,   312,   316,   322,   326,   327,   332,   333,   334,   335,
   339,   340,   341,   342,   346,   354,   362,   369,   373,   374,
   375,   376,   377,   381,   388,   392,   393,   397,   398,   399,
   400,   404,   408,   409,   413,   414,   415,   419,   420,   424,
   425,   426,   427,   428,   432,   436,   437,   438,   439,   440,
   444,   445,   446,   447,   448,   452,   453,   457,   461,   462,
   466,   467,   471,   472,   473,   477,   478,   479,   483,   484
};
#endif


#if YYDEBUG != 0 || defined (YYERROR_VERBOSE)

static const char * const yytname[] = {   "$","error","$undefined.","KW_SOURCE",
"KW_DESTINATION","KW_LOG","KW_OPTIONS","KW_FILTER","KW_INTERNAL","KW_FILE","KW_UNIX_STREAM",
"KW_UNIX_DGRAM","KW_UDP","KW_TCP","KW_USER","KW_DOOR","KW_SUN_STREAMS","KW_MARK_FREQ",
"KW_SYNC_FREQ","KW_LONG_HOSTNAMES","KW_LOG_FIFO_SIZE","KW_TIME_REOPEN","KW_OWNER",
"KW_GROUP","KW_PERM","KW_LOCALIP","KW_IP","KW_LOCALPORT","KW_PORT","KW_DESTPORT",
"KW_COMPRESS","KW_MAC","KW_AUTH","KW_ENCRYPT","KW_FACILITY","KW_LEVEL","KW_PROGRAM",
"KW_HOST","KW_MATCH","KW_YES","KW_NO","KW_REQUIRED","KW_ALLOW","KW_DENY","DOTDOT",
"IDENTIFIER","NUMBER","STRING","KW_OR","KW_AND","KW_NOT","';'","'{'","'}'","'('",
"')'","','","start","stmts","stmt","source_stmt","dest_stmt","log_stmt","options_stmt",
"source_items","source_item","source_afinter","source_affile","source_afsocket",
"source_afunix_dgram_params","@1","source_afunix_stream_params","@2","source_afunix_options",
"source_afunix_option","source_afinet_udp_params","@3","source_afinet_udp_options",
"source_afinet_udp_option","source_afinet_tcp_params","@4","source_afinet_tcp_options",
"source_afinet_tcp_option","source_afstreams","source_afstreams_params","@5",
"source_afstreams_options","source_afstreams_option","dest_items","dest_item",
"dest_item_option","dest_affile","dest_affile_params","@6","dest_affile_options",
"dest_affile_option","dest_afsocket","dest_afunix_dgram_params","dest_afunix_stream_params",
"dest_afinet_udp_params","@7","dest_afinet_udp_options","dest_afinet_tcp_params",
"@8","dest_afinet_tcp_options","dest_afinet_tcp_option","dest_afuser","log_items",
"log_item","options_items","options_item","filter_stmt","filter_expr","filter_simple_expr",
"filter_fac_list","filter_fac","filter_level_list","filter_level","yesno","tripleoption",
"string", NULL
};
#endif

static const short yyr1[] = {     0,
    57,    58,    58,    59,    59,    59,    59,    59,    60,    61,
    62,    63,    64,    64,    65,    65,    65,    65,    66,    67,
    68,    68,    68,    68,    70,    69,    72,    71,    73,    73,
    74,    74,    74,    76,    75,    77,    77,    78,    78,    78,
    78,    80,    79,    81,    81,    82,    82,    82,    82,    83,
    85,    84,    86,    86,    87,    88,    88,    89,    89,    89,
    90,    91,    93,    92,    94,    94,    95,    95,    95,    95,
    96,    96,    96,    96,    97,    98,   100,    99,   101,   101,
   101,   101,   101,   103,   102,   104,   104,   105,   105,   105,
   105,   106,   107,   107,   108,   108,   108,   109,   109,   110,
   110,   110,   110,   110,   111,   112,   112,   112,   112,   112,
   113,   113,   113,   113,   113,   114,   114,   115,   116,   116,
   117,   117,   118,   118,   118,   119,   119,   119,   120,   120
};

static const short yyr2[] = {     0,
     1,     3,     0,     2,     2,     2,     2,     2,     4,     4,
     3,     3,     3,     0,     1,     1,     1,     1,     3,     4,
     4,     4,     4,     4,     0,     3,     0,     3,     2,     0,
     4,     4,     4,     0,     2,     2,     0,     4,     4,     4,
     4,     0,     2,     2,     0,     1,     4,     4,     4,     4,
     0,     3,     2,     0,     4,     3,     0,     1,     1,     1,
     4,     4,     0,     3,     2,     0,     1,     4,     4,     4,
     4,     4,     4,     4,     1,     1,     0,     3,     1,     4,
     4,     4,     4,     0,     3,     2,     0,     1,     4,     4,
     4,     4,     3,     0,     4,     4,     4,     3,     0,     4,
     4,     4,     4,     4,     5,     1,     2,     3,     3,     3,
     4,     4,     4,     4,     4,     3,     1,     1,     3,     1,
     1,     3,     1,     1,     1,     1,     1,     1,     1,     1
};

static const short yydefact[] = {     3,
     0,     0,     0,     0,     0,     1,     0,   129,   130,     4,
     0,     5,     0,    94,     6,    99,     8,     7,     0,     3,
    14,    57,     0,     0,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     2,     0,     0,     0,     0,
     0,     0,     0,     0,     0,    15,    16,    17,    18,     0,
     0,     0,     0,     0,     0,     0,     0,    58,    59,    60,
     0,     0,     0,    11,    94,     0,     0,     0,     0,     0,
    12,    99,     0,     0,     0,     0,     0,     0,     0,     0,
   106,     0,     0,     0,     0,    34,    42,     0,     9,    14,
     0,     0,     0,     0,     0,     0,    10,    57,     0,     0,
     0,    93,     0,     0,   123,   124,   125,     0,     0,     0,
    98,     0,     0,     0,     0,     0,   107,     0,     0,     0,
     0,    19,     0,     0,    27,     0,    25,     0,    37,     0,
    45,     0,    51,    13,     0,    63,     0,    76,     0,    75,
     0,    77,     0,    84,     0,    56,    95,    97,    96,   100,
   101,   102,   104,   103,   118,     0,   117,   121,     0,   120,
     0,     0,     0,   110,   108,   109,   105,    20,    22,    30,
    21,    30,    23,     0,     0,     0,     0,    35,    37,    24,
     0,     0,     0,    46,    43,    45,    50,    54,    62,    66,
    72,    71,    73,     0,    74,    87,    92,   111,     0,     0,
   112,     0,   113,   114,   115,     0,     0,     0,    28,    30,
    26,     0,     0,     0,     0,    36,     0,     0,     0,    44,
     0,    52,    54,     0,     0,     0,     0,    67,    64,    66,
     0,     0,     0,     0,    79,    78,     0,     0,     0,    88,
    85,    87,   116,   122,   119,     0,     0,     0,    29,     0,
     0,     0,     0,   126,   127,   128,     0,     0,     0,     0,
    53,     0,     0,     0,     0,    65,     0,     0,     0,     0,
     0,     0,     0,    86,     0,     0,     0,    38,    39,    40,
    41,    48,    47,    49,     0,     0,     0,     0,     0,     0,
     0,     0,     0,     0,     0,     0,    31,    32,    33,    55,
    68,    61,    69,    70,    80,    81,    82,    83,    89,    90,
    91,     0,     0,     0
};

static const short yydefgoto[] = {   312,
     6,     7,    10,    12,    15,    17,    44,    45,    46,    47,
    48,   126,   172,   124,   170,   209,   210,   128,   129,   178,
   179,   130,   131,   185,   186,    49,   132,   188,   222,   223,
    56,    57,   235,    58,   135,   190,   229,   230,    59,   139,
   137,   141,   194,   240,   143,   196,   241,   242,    60,    26,
    27,    33,    34,    18,    80,    81,   156,   157,   159,   160,
   108,   257,    11
};

static const short yypact[] = {    98,
   -31,   -31,   -34,   -30,   -31,-32768,   -25,-32768,-32768,-32768,
   -22,-32768,   -18,    72,-32768,    89,-32768,-32768,    -9,    98,
    42,    86,     3,    20,    26,    24,    60,    34,    71,    73,
    74,    75,    77,    80,   -27,-32768,    78,    79,    82,    83,
    84,    85,    87,    91,    92,-32768,-32768,-32768,-32768,    88,
    93,    94,    95,    96,    99,   101,   100,-32768,-32768,-32768,
   -31,   -31,   -31,-32768,    72,   106,   109,    27,   110,   111,
-32768,    89,   104,   105,   107,   108,   112,   -27,   -27,    36,
-32768,   113,   -31,   -31,   -31,-32768,-32768,   -31,-32768,    42,
   -31,   -31,   -31,   -31,   -31,   -31,-32768,    86,   114,   115,
   116,-32768,   117,   118,-32768,-32768,-32768,   119,   120,   121,
-32768,   122,   132,   -31,   -31,   -31,-32768,    23,   -27,   -27,
   125,-32768,   124,   126,-32768,   127,-32768,   128,    90,   129,
    37,   130,-32768,-32768,   131,-32768,   133,-32768,   134,-32768,
   135,-32768,   136,-32768,   137,-32768,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,   138,    70,   102,   139,   140,
   142,   143,   144,-32768,   146,-32768,-32768,-32768,-32768,    97,
-32768,    97,-32768,   147,   148,   149,   150,-32768,    90,-32768,
   151,   152,   153,-32768,-32768,    37,-32768,   145,-32768,    -5,
-32768,-32768,-32768,    -8,-32768,     4,-32768,-32768,   122,   155,
-32768,   132,-32768,-32768,-32768,   154,   158,   159,-32768,    97,
-32768,   -31,   -31,   141,   163,-32768,    81,    81,    81,-32768,
   160,-32768,   145,   161,   162,   164,   165,-32768,-32768,    -5,
   166,   167,   168,   169,-32768,-32768,   170,   171,   172,-32768,
-32768,     4,-32768,-32768,-32768,   -31,   -31,   181,-32768,   173,
   174,   175,   176,-32768,-32768,-32768,   177,   178,   179,   -31,
-32768,   189,   190,    27,    27,-32768,   -31,   191,   192,   193,
    27,    27,    27,-32768,   185,   186,   187,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,   188,   194,   195,   196,   197,   198,
   199,   200,   201,   202,   204,   205,-32768,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,-32768,
-32768,   180,   217,-32768
};

static const short yypgoto[] = {-32768,
   226,-32768,-32768,-32768,-32768,-32768,    44,-32768,-32768,-32768,
-32768,-32768,-32768,-32768,-32768,  -166,-32768,-32768,-32768,   -44,
  -130,-32768,-32768,   -46,-32768,-32768,-32768,-32768,   -78,-32768,
    65,-32768,  -188,-32768,-32768,-32768,   -66,-32768,-32768,-32768,
-32768,-32768,-32768,   -29,-32768,-32768,     5,-32768,-32768,   183,
-32768,   203,-32768,-32768,   -74,-32768,    62,-32768,    61,-32768,
  -224,  -180,    -2
};


#define	YYLAST		275


static const short yytable[] = {    13,
   184,   228,    19,   117,   118,   211,    73,    74,    75,    76,
    77,   225,   224,     8,   225,     9,   231,    14,   232,   233,
   234,    16,    78,   225,   226,    20,    79,   227,   231,    21,
   232,   233,   234,    22,   237,   238,   239,   258,   259,   288,
   289,   228,    35,   249,   165,   166,   294,   295,   296,    37,
    38,    39,    40,    41,    42,   184,    61,    43,    99,   100,
   101,   174,   175,   176,   177,   105,   106,   181,   182,   183,
   119,   120,   107,    62,    23,    24,    64,   164,    25,    63,
   123,   125,   127,   119,   120,   133,   121,    66,   136,   138,
   140,   142,   144,   145,    50,    51,    52,    53,    54,    55,
     1,     2,     3,     4,     5,    28,    29,    30,    31,    32,
    65,   161,   162,   163,   174,   175,   176,   177,   206,   207,
   208,   254,   255,   256,    67,   199,    68,    69,    70,    71,
    72,    82,    83,   134,   216,    84,    85,    86,    87,   220,
    88,    91,    90,    89,   261,   200,    92,    93,    94,    95,
    98,   103,    96,    97,   104,   109,   110,   112,   113,   221,
   114,   115,   146,   266,   236,   116,   155,   122,   147,   148,
   149,   150,   151,   152,   153,   154,   158,   167,   168,   313,
   169,   171,   173,   180,   187,   189,   252,   191,   192,   193,
   195,   197,   198,   201,   120,   202,   203,   204,   205,   244,
   212,   213,   214,   215,   217,   218,   219,   246,   253,   250,
   251,   247,   248,   260,   262,   263,   314,   264,   265,   267,
   268,   269,   270,   271,   272,   273,   277,   278,   279,   280,
   281,   282,   283,   284,   286,   287,   291,   292,   293,   297,
   298,   299,   300,   275,   276,    36,   274,   102,   301,   302,
   303,   304,   305,   306,   307,   308,   309,   285,   310,   311,
   243,     0,   245,     0,   290,     0,     0,     0,     0,     0,
     0,     0,     0,     0,   111
};

static const short yycheck[] = {     2,
   131,   190,     5,    78,    79,   172,    34,    35,    36,    37,
    38,    20,    18,    45,    20,    47,    25,    52,    27,    28,
    29,    52,    50,    20,    30,    51,    54,    33,    25,    52,
    27,    28,    29,    52,    31,    32,    33,   218,   219,   264,
   265,   230,    52,   210,   119,   120,   271,   272,   273,     8,
     9,    10,    11,    12,    13,   186,    54,    16,    61,    62,
    63,    25,    26,    27,    28,    39,    40,    31,    32,    33,
    48,    49,    46,    54,     3,     4,    53,    55,     7,    54,
    83,    84,    85,    48,    49,    88,    51,    54,    91,    92,
    93,    94,    95,    96,     9,    10,    11,    12,    13,    14,
     3,     4,     5,     6,     7,    17,    18,    19,    20,    21,
    51,   114,   115,   116,    25,    26,    27,    28,    22,    23,
    24,    41,    42,    43,    54,    56,    54,    54,    54,    53,
    51,    54,    54,    90,   179,    54,    54,    54,    54,   186,
    54,    54,    51,    53,   223,    44,    54,    54,    54,    54,
    51,    46,    54,    53,    46,    46,    46,    54,    54,    15,
    54,    54,    98,   230,   194,    54,    45,    55,    55,    55,
    55,    55,    55,    55,    55,    55,    45,    53,    55,     0,
    55,    55,    55,    55,    55,    55,    46,    55,    55,    55,
    55,    55,    55,    55,    49,    56,    55,    55,    55,    45,
    54,    54,    54,    54,    54,    54,    54,    54,    46,   212,
   213,    54,    54,    54,    54,    54,     0,    54,    54,    54,
    54,    54,    54,    54,    54,    54,    46,    55,    55,    55,
    55,    55,    55,    55,    46,    46,    46,    46,    46,    55,
    55,    55,    55,   246,   247,    20,   242,    65,    55,    55,
    55,    55,    55,    55,    55,    55,    55,   260,    55,    55,
   199,    -1,   202,    -1,   267,    -1,    -1,    -1,    -1,    -1,
    -1,    -1,    -1,    -1,    72
};
/* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
#line 3 "/usr/share/misc/bison.simple"
/* This file comes from bison-1.27.  */

/* Skeleton output parser for bison,
   Copyright (C) 1984, 1989, 1990 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* This is the parser code that is written into each bison parser
  when the %semantic_parser declaration is not specified in the grammar.
  It was written by Richard Stallman by simplifying the hairy parser
  used when %semantic_parser is specified.  */

#ifndef YYSTACK_USE_ALLOCA
#ifdef alloca
#define YYSTACK_USE_ALLOCA
#else /* alloca not defined */
#ifdef __GNUC__
#define YYSTACK_USE_ALLOCA
#define alloca __builtin_alloca
#else /* not GNU C.  */
#if (!defined (__STDC__) && defined (sparc)) || defined (__sparc__) || defined (__sparc) || defined (__sgi) || (defined (__sun) && defined (__i386))
#define YYSTACK_USE_ALLOCA
#include <alloca.h>
#else /* not sparc */
/* We think this test detects Watcom and Microsoft C.  */
/* This used to test MSDOS, but that is a bad idea
   since that symbol is in the user namespace.  */
#if (defined (_MSDOS) || defined (_MSDOS_)) && !defined (__TURBOC__)
#if 0 /* No need for malloc.h, which pollutes the namespace;
	 instead, just don't use alloca.  */
#include <malloc.h>
#endif
#else /* not MSDOS, or __TURBOC__ */
#if defined(_AIX)
/* I don't know what this was needed for, but it pollutes the namespace.
   So I turned it off.   rms, 2 May 1997.  */
/* #include <malloc.h>  */
 #pragma alloca
#define YYSTACK_USE_ALLOCA
#else /* not MSDOS, or __TURBOC__, or _AIX */
#if 0
#ifdef __hpux /* haible@ilog.fr says this works for HPUX 9.05 and up,
		 and on HPUX 10.  Eventually we can turn this on.  */
#define YYSTACK_USE_ALLOCA
#define alloca __builtin_alloca
#endif /* __hpux */
#endif
#endif /* not _AIX */
#endif /* not MSDOS, or __TURBOC__ */
#endif /* not sparc */
#endif /* not GNU C */
#endif /* alloca not defined */
#endif /* YYSTACK_USE_ALLOCA not defined */

#ifdef YYSTACK_USE_ALLOCA
#define YYSTACK_ALLOC alloca
#else
#define YYSTACK_ALLOC malloc
#endif

/* Note: there must be only one dollar sign in this file.
   It is replaced by the list of actions, each action
   as one case of the switch.  */

#define yyerrok		(yyerrstatus = 0)
#define yyclearin	(yychar = YYEMPTY)
#define YYEMPTY		-2
#define YYEOF		0
#define YYACCEPT	goto yyacceptlab
#define YYABORT 	goto yyabortlab
#define YYERROR		goto yyerrlab1
/* Like YYERROR except do call yyerror.
   This remains here temporarily to ease the
   transition to the new meaning of YYERROR, for GCC.
   Once GCC version 2 has supplanted version 1, this can go.  */
#define YYFAIL		goto yyerrlab
#define YYRECOVERING()  (!!yyerrstatus)
#define YYBACKUP(token, value) \
do								\
  if (yychar == YYEMPTY && yylen == 1)				\
    { yychar = (token), yylval = (value);			\
      yychar1 = YYTRANSLATE (yychar);				\
      YYPOPSTACK;						\
      goto yybackup;						\
    }								\
  else								\
    { yyerror ("syntax error: cannot back up"); YYERROR; }	\
while (0)

#define YYTERROR	1
#define YYERRCODE	256

#ifndef YYPURE
#define YYLEX		yylex()
#endif

#ifdef YYPURE
#ifdef YYLSP_NEEDED
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, &yylloc, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval, &yylloc)
#endif
#else /* not YYLSP_NEEDED */
#ifdef YYLEX_PARAM
#define YYLEX		yylex(&yylval, YYLEX_PARAM)
#else
#define YYLEX		yylex(&yylval)
#endif
#endif /* not YYLSP_NEEDED */
#endif

/* If nonreentrant, generate the variables here */

#ifndef YYPURE

int	yychar;			/*  the lookahead symbol		*/
YYSTYPE	yylval;			/*  the semantic value of the		*/
				/*  lookahead symbol			*/

#ifdef YYLSP_NEEDED
YYLTYPE yylloc;			/*  location data for the lookahead	*/
				/*  symbol				*/
#endif

int yynerrs;			/*  number of parse errors so far       */
#endif  /* not YYPURE */

#if YYDEBUG != 0
int yydebug;			/*  nonzero means print parse trace	*/
/* Since this is uninitialized, it does not stop multiple parsers
   from coexisting.  */
#endif

/*  YYINITDEPTH indicates the initial size of the parser's stacks	*/

#ifndef	YYINITDEPTH
#define YYINITDEPTH 200
#endif

/*  YYMAXDEPTH is the maximum size the stacks can grow to
    (effective only if the built-in stack extension method is used).  */

#if YYMAXDEPTH == 0
#undef YYMAXDEPTH
#endif

#ifndef YYMAXDEPTH
#define YYMAXDEPTH 10000
#endif

/* Define __yy_memcpy.  Note that the size argument
   should be passed with type unsigned int, because that is what the non-GCC
   definitions require.  With GCC, __builtin_memcpy takes an arg
   of type size_t, but it can handle unsigned int.  */

#if __GNUC__ > 1		/* GNU C and GNU C++ define this.  */
#define __yy_memcpy(TO,FROM,COUNT)	__builtin_memcpy(TO,FROM,COUNT)
#else				/* not GNU C or C++ */
#ifndef __cplusplus

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (to, from, count)
     char *to;
     char *from;
     unsigned int count;
{
  register char *f = from;
  register char *t = to;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#else /* __cplusplus */

/* This is the most reliable way to avoid incompatibilities
   in available built-in functions on various systems.  */
static void
__yy_memcpy (char *to, char *from, unsigned int count)
{
  register char *t = to;
  register char *f = from;
  register int i = count;

  while (i-- > 0)
    *t++ = *f++;
}

#endif
#endif

#line 216 "/usr/share/misc/bison.simple"

/* The user can define YYPARSE_PARAM as the name of an argument to be passed
   into yyparse.  The argument should have type void *.
   It should actually point to an object.
   Grammar actions can access the variable by casting it
   to the proper pointer type.  */

#ifdef YYPARSE_PARAM
#ifdef __cplusplus
#define YYPARSE_PARAM_ARG void *YYPARSE_PARAM
#define YYPARSE_PARAM_DECL
#else /* not __cplusplus */
#define YYPARSE_PARAM_ARG YYPARSE_PARAM
#define YYPARSE_PARAM_DECL void *YYPARSE_PARAM;
#endif /* not __cplusplus */
#else /* not YYPARSE_PARAM */
#define YYPARSE_PARAM_ARG
#define YYPARSE_PARAM_DECL
#endif /* not YYPARSE_PARAM */

/* Prevent warning if -Wstrict-prototypes.  */
#ifdef __GNUC__
#ifdef YYPARSE_PARAM
int yyparse (void *);
#else
int yyparse (void);
#endif
#endif

int
yyparse(YYPARSE_PARAM_ARG)
     YYPARSE_PARAM_DECL
{
  register int yystate;
  register int yyn;
  register short *yyssp;
  register YYSTYPE *yyvsp;
  int yyerrstatus;	/*  number of tokens to shift before error messages enabled */
  int yychar1 = 0;		/*  lookahead token as an internal (translated) token number */

  short	yyssa[YYINITDEPTH];	/*  the state stack			*/
  YYSTYPE yyvsa[YYINITDEPTH];	/*  the semantic value stack		*/

  short *yyss = yyssa;		/*  refer to the stacks thru separate pointers */
  YYSTYPE *yyvs = yyvsa;	/*  to allow yyoverflow to reallocate them elsewhere */

#ifdef YYLSP_NEEDED
  YYLTYPE yylsa[YYINITDEPTH];	/*  the location stack			*/
  YYLTYPE *yyls = yylsa;
  YYLTYPE *yylsp;

#define YYPOPSTACK   (yyvsp--, yyssp--, yylsp--)
#else
#define YYPOPSTACK   (yyvsp--, yyssp--)
#endif

  int yystacksize = YYINITDEPTH;
  int yyfree_stacks = 0;

#ifdef YYPURE
  int yychar;
  YYSTYPE yylval;
  int yynerrs;
#ifdef YYLSP_NEEDED
  YYLTYPE yylloc;
#endif
#endif

  YYSTYPE yyval;		/*  the variable used to return		*/
				/*  semantic values from the action	*/
				/*  routines				*/

  int yylen;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Starting parse\n");
#endif

  yystate = 0;
  yyerrstatus = 0;
  yynerrs = 0;
  yychar = YYEMPTY;		/* Cause a token to be read.  */

  /* Initialize stack pointers.
     Waste one element of value and location stack
     so that they stay on the same level as the state stack.
     The wasted elements are never initialized.  */

  yyssp = yyss - 1;
  yyvsp = yyvs;
#ifdef YYLSP_NEEDED
  yylsp = yyls;
#endif

/* Push a new state, which is found in  yystate  .  */
/* In all cases, when you get here, the value and location stacks
   have just been pushed. so pushing a state here evens the stacks.  */
yynewstate:

  *++yyssp = yystate;

  if (yyssp >= yyss + yystacksize - 1)
    {
      /* Give user a chance to reallocate the stack */
      /* Use copies of these so that the &'s don't force the real ones into memory. */
      YYSTYPE *yyvs1 = yyvs;
      short *yyss1 = yyss;
#ifdef YYLSP_NEEDED
      YYLTYPE *yyls1 = yyls;
#endif

      /* Get the current used size of the three stacks, in elements.  */
      int size = yyssp - yyss + 1;

#ifdef yyoverflow
      /* Each stack pointer address is followed by the size of
	 the data in use in that stack, in bytes.  */
#ifdef YYLSP_NEEDED
      /* This used to be a conditional around just the two extra args,
	 but that might be undefined if yyoverflow is a macro.  */
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yyls1, size * sizeof (*yylsp),
		 &yystacksize);
#else
      yyoverflow("parser stack overflow",
		 &yyss1, size * sizeof (*yyssp),
		 &yyvs1, size * sizeof (*yyvsp),
		 &yystacksize);
#endif

      yyss = yyss1; yyvs = yyvs1;
#ifdef YYLSP_NEEDED
      yyls = yyls1;
#endif
#else /* no yyoverflow */
      /* Extend the stack our own way.  */
      if (yystacksize >= YYMAXDEPTH)
	{
	  yyerror("parser stack overflow");
	  if (yyfree_stacks)
	    {
	      free (yyss);
	      free (yyvs);
#ifdef YYLSP_NEEDED
	      free (yyls);
#endif
	    }
	  return 2;
	}
      yystacksize *= 2;
      if (yystacksize > YYMAXDEPTH)
	yystacksize = YYMAXDEPTH;
#ifndef YYSTACK_USE_ALLOCA
      yyfree_stacks = 1;
#endif
      yyss = (short *) YYSTACK_ALLOC (yystacksize * sizeof (*yyssp));
      __yy_memcpy ((char *)yyss, (char *)yyss1,
		   size * (unsigned int) sizeof (*yyssp));
      yyvs = (YYSTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yyvsp));
      __yy_memcpy ((char *)yyvs, (char *)yyvs1,
		   size * (unsigned int) sizeof (*yyvsp));
#ifdef YYLSP_NEEDED
      yyls = (YYLTYPE *) YYSTACK_ALLOC (yystacksize * sizeof (*yylsp));
      __yy_memcpy ((char *)yyls, (char *)yyls1,
		   size * (unsigned int) sizeof (*yylsp));
#endif
#endif /* no yyoverflow */

      yyssp = yyss + size - 1;
      yyvsp = yyvs + size - 1;
#ifdef YYLSP_NEEDED
      yylsp = yyls + size - 1;
#endif

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Stack size increased to %d\n", yystacksize);
#endif

      if (yyssp >= yyss + yystacksize - 1)
	YYABORT;
    }

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Entering state %d\n", yystate);
#endif

  goto yybackup;
 yybackup:

/* Do appropriate processing given the current state.  */
/* Read a lookahead token if we need one and don't already have one.  */
/* yyresume: */

  /* First try to decide what to do without reference to lookahead token.  */

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* yychar is either YYEMPTY or YYEOF
     or a valid token in external form.  */

  if (yychar == YYEMPTY)
    {
#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Reading a token: ");
#endif
      yychar = YYLEX;
    }

  /* Convert token to internal form (in yychar1) for indexing tables with */

  if (yychar <= 0)		/* This means end of input. */
    {
      yychar1 = 0;
      yychar = YYEOF;		/* Don't call YYLEX any more */

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Now at end of input.\n");
#endif
    }
  else
    {
      yychar1 = YYTRANSLATE(yychar);

#if YYDEBUG != 0
      if (yydebug)
	{
	  fprintf (stderr, "Next token is %d (%s", yychar, yytname[yychar1]);
	  /* Give the individual parser a way to print the precise meaning
	     of a token, for further debugging info.  */
#ifdef YYPRINT
	  YYPRINT (stderr, yychar, yylval);
#endif
	  fprintf (stderr, ")\n");
	}
#endif
    }

  yyn += yychar1;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != yychar1)
    goto yydefault;

  yyn = yytable[yyn];

  /* yyn is what to do for this token type in this state.
     Negative => reduce, -yyn is rule number.
     Positive => shift, yyn is new state.
       New state is final state => don't bother to shift,
       just return success.
     0, or most negative number => error.  */

  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrlab;

  if (yyn == YYFINAL)
    YYACCEPT;

  /* Shift the lookahead token.  */

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting token %d (%s), ", yychar, yytname[yychar1]);
#endif

  /* Discard the token being shifted unless it is eof.  */
  if (yychar != YYEOF)
    yychar = YYEMPTY;

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  /* count tokens shifted since error; after three, turn off error status.  */
  if (yyerrstatus) yyerrstatus--;

  yystate = yyn;
  goto yynewstate;

/* Do the default action for the current state.  */
yydefault:

  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;

/* Do a reduction.  yyn is the number of a rule to reduce with.  */
yyreduce:
  yylen = yyr2[yyn];
  if (yylen > 0)
    yyval = yyvsp[1-yylen]; /* implement default value of the action */

#if YYDEBUG != 0
  if (yydebug)
    {
      int i;

      fprintf (stderr, "Reducing via rule %d (line %d), ",
	       yyn, yyrline[yyn]);

      /* Print the symbols being reduced, and their result.  */
      for (i = yyprhs[yyn]; yyrhs[i] > 0; i++)
	fprintf (stderr, "%s ", yytname[yyrhs[i]]);
      fprintf (stderr, " -> %s\n", yytname[yyr1[yyn]]);
    }
#endif


  switch (yyn) {

case 4:
#line 145 "cfg-grammar.y"
{ add_source_group(yyvsp[0].ptr); ;
    break;}
case 5:
#line 146 "cfg-grammar.y"
{ add_dest_group(yyvsp[0].ptr); ;
    break;}
case 6:
#line 147 "cfg-grammar.y"
{ add_log_connection(yyvsp[0].ptr); ;
    break;}
case 7:
#line 148 "cfg-grammar.y"
{ add_filter_rule(yyvsp[0].ptr); ;
    break;}
case 8:
#line 149 "cfg-grammar.y"
{  ;
    break;}
case 9:
#line 153 "cfg-grammar.y"
{ yyval.ptr = make_source_group(yyvsp[-3].cptr, yyvsp[-1].ptr); free(yyvsp[-3].cptr); ;
    break;}
case 10:
#line 157 "cfg-grammar.y"
{ yyval.ptr = make_dest_group(yyvsp[-3].cptr, yyvsp[-1].ptr); free(yyvsp[-3].cptr); ;
    break;}
case 11:
#line 161 "cfg-grammar.y"
{ yyval.ptr = make_log_connection(yyvsp[-1].ptr); ;
    break;}
case 12:
#line 165 "cfg-grammar.y"
{ yyval.ptr = NULL; ;
    break;}
case 13:
#line 169 "cfg-grammar.y"
{ append_source_driver(yyvsp[-2].ptr, yyvsp[0].ptr); yyval.ptr = yyvsp[-2].ptr; ;
    break;}
case 14:
#line 170 "cfg-grammar.y"
{ yyval.ptr = NULL; ;
    break;}
case 15:
#line 174 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; ;
    break;}
case 16:
#line 175 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; ;
    break;}
case 17:
#line 176 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; ;
    break;}
case 18:
#line 177 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; ;
    break;}
case 19:
#line 181 "cfg-grammar.y"
{ yyval.ptr = make_afinter_source(); ;
    break;}
case 20:
#line 185 "cfg-grammar.y"
{ yyval.ptr = make_affile_source(yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 21:
#line 189 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 22:
#line 190 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 23:
#line 191 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 24:
#line 192 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 25:
#line 197 "cfg-grammar.y"
{ 
	    last_source_driver = make_afsocket_source(
		&make_unix_address_c(yyvsp[0].cptr)->super, 
		AFUNIX_PROTO_DGRAM); 
	    free(yyvsp[0].cptr); 
	  ;
    break;}
case 26:
#line 203 "cfg-grammar.y"
{ yyval.ptr = last_source_driver; ;
    break;}
case 27:
#line 208 "cfg-grammar.y"
{ 
	    last_source_driver = make_afsocket_source(
		&make_unix_address_c(yyvsp[0].cptr)->super,
		AFUNIX_PROTO_STREAM);
	    free(yyvsp[0].cptr);
	  ;
    break;}
case 28:
#line 214 "cfg-grammar.y"
{ yyval.ptr = last_source_driver; ;
    break;}
case 31:
#line 224 "cfg-grammar.y"
{ afunix_set_owner(last_source_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 32:
#line 225 "cfg-grammar.y"
{ afunix_set_group(last_source_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 33:
#line 226 "cfg-grammar.y"
{ afunix_set_perm(last_source_driver, yyvsp[-1].num); ;
    break;}
case 34:
#line 231 "cfg-grammar.y"
{ 
	    last_source_driver = make_afsocket_source(
			&make_inet_address_c("0.0.0.0", "514")->super, 
			AFINET_PROTO_DGRAM);
	  ;
    break;}
case 35:
#line 236 "cfg-grammar.y"
{ yyval.ptr = last_source_driver; ;
    break;}
case 38:
#line 245 "cfg-grammar.y"
{ afinet_src_set_localip(last_source_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 39:
#line 246 "cfg-grammar.y"
{ afinet_src_set_localip(last_source_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 40:
#line 247 "cfg-grammar.y"
{ afinet_src_set_localport(last_source_driver, yyvsp[-1].num); ;
    break;}
case 41:
#line 248 "cfg-grammar.y"
{ afinet_src_set_localport(last_source_driver, yyvsp[-1].num); ;
    break;}
case 42:
#line 254 "cfg-grammar.y"
{ 
	    last_source_driver = make_afsocket_source(
			&make_inet_address_c("0.0.0.0", "514")->super,
			AFINET_PROTO_STREAM);
	  ;
    break;}
case 43:
#line 259 "cfg-grammar.y"
{ yyval.ptr = last_source_driver; ;
    break;}
case 47:
#line 269 "cfg-grammar.y"
{ afinet_src_set_auth(last_source_driver, yyvsp[-1].num); ;
    break;}
case 48:
#line 270 "cfg-grammar.y"
{ afinet_src_set_mac(last_source_driver, yyvsp[-1].num); ;
    break;}
case 49:
#line 271 "cfg-grammar.y"
{ afinet_src_set_encrypt(last_source_driver, yyvsp[-1].num); ;
    break;}
case 50:
#line 275 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 51:
#line 280 "cfg-grammar.y"
{ 
	    last_source_driver = make_afstreams_source(yyvsp[0].cptr); 
	    free(yyvsp[0].cptr); 
	  ;
    break;}
case 52:
#line 284 "cfg-grammar.y"
{ yyval.ptr = last_source_driver; ;
    break;}
case 55:
#line 293 "cfg-grammar.y"
{ afstreams_set_sundoor(last_source_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 56:
#line 297 "cfg-grammar.y"
{ append_dest_driver(yyvsp[-2].ptr, yyvsp[0].ptr); yyval.ptr = yyvsp[-2].ptr; ;
    break;}
case 57:
#line 298 "cfg-grammar.y"
{ yyval.ptr = NULL; ;
    break;}
case 58:
#line 302 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; ;
    break;}
case 59:
#line 303 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; ;
    break;}
case 60:
#line 304 "cfg-grammar.y"
{ yyval.ptr = yyvsp[0].ptr; ;
    break;}
case 61:
#line 308 "cfg-grammar.y"
{ last_dest_driver->log_fifo_size = yyvsp[-1].num; ;
    break;}
case 62:
#line 312 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 63:
#line 317 "cfg-grammar.y"
{ 
	    last_dest_driver = make_affile_dest(yyvsp[0].cptr, 0); 
	    free(yyvsp[0].cptr); 
	  ;
    break;}
case 64:
#line 322 "cfg-grammar.y"
{ yyval.ptr = last_dest_driver; ;
    break;}
case 68:
#line 333 "cfg-grammar.y"
{ affile_set_syncfreq(last_dest_driver, yyvsp[-1].num); ;
    break;}
case 69:
#line 334 "cfg-grammar.y"
{ affile_set_compress(last_dest_driver, yyvsp[-1].num); ;
    break;}
case 70:
#line 335 "cfg-grammar.y"
{ affile_set_encrypt(last_dest_driver, yyvsp[-1].num); ;
    break;}
case 71:
#line 339 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 72:
#line 340 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 73:
#line 341 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 74:
#line 342 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-1].ptr; ;
    break;}
case 75:
#line 346 "cfg-grammar.y"
{ yyval.ptr = make_afsocket_dest(
							&make_unix_address_c(yyvsp[0].cptr)->super, 
							AFUNIX_PROTO_DGRAM);
							free(yyvsp[0].cptr);
						;
    break;}
case 76:
#line 354 "cfg-grammar.y"
{ yyval.ptr = make_afsocket_dest(
							&make_unix_address_c(yyvsp[0].cptr)->super, 
							AFUNIX_PROTO_STREAM);
							free(yyvsp[0].cptr);
						;
    break;}
case 77:
#line 363 "cfg-grammar.y"
{ 
	    last_dest_driver = make_afsocket_dest(
			&make_inet_address_c(yyvsp[0].cptr, "514")->super, 
			AFINET_PROTO_DGRAM);
	    free(yyvsp[0].cptr);
	  ;
    break;}
case 78:
#line 369 "cfg-grammar.y"
{ yyval.ptr = last_dest_driver; ;
    break;}
case 80:
#line 374 "cfg-grammar.y"
{ afinet_dest_set_localip(last_dest_driver, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 81:
#line 375 "cfg-grammar.y"
{ afinet_dest_set_localport(last_dest_driver, yyvsp[-1].num); ;
    break;}
case 82:
#line 376 "cfg-grammar.y"
{ afinet_dest_set_destport(last_dest_driver, yyvsp[-1].num); ;
    break;}
case 83:
#line 377 "cfg-grammar.y"
{ afinet_dest_set_destport(last_dest_driver, yyvsp[-1].num); ;
    break;}
case 84:
#line 382 "cfg-grammar.y"
{ 
	    last_dest_driver = make_afsocket_dest(
			&make_inet_address_c(yyvsp[0].cptr, "514")->super, 
			AFINET_PROTO_STREAM); 
	    free(yyvsp[0].cptr);
	  ;
    break;}
case 85:
#line 388 "cfg-grammar.y"
{ yyval.ptr = last_dest_driver; ;
    break;}
case 92:
#line 404 "cfg-grammar.y"
{ yyval.ptr = make_afuser_dest(yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 93:
#line 408 "cfg-grammar.y"
{ append_endpoint_info(yyvsp[-2].ptr, yyvsp[0].ptr); yyval.ptr = yyvsp[-2].ptr; ;
    break;}
case 94:
#line 409 "cfg-grammar.y"
{ yyval.ptr = NULL; ;
    break;}
case 95:
#line 413 "cfg-grammar.y"
{ yyval.ptr = make_log_endpoint_info(EP_SOURCE, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 96:
#line 414 "cfg-grammar.y"
{ yyval.ptr = make_log_endpoint_info(EP_FILTER, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 97:
#line 415 "cfg-grammar.y"
{ yyval.ptr = make_log_endpoint_info(EP_DESTINATION, yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 98:
#line 419 "cfg-grammar.y"
{ yyval.ptr = yyvsp[-2].ptr; ;
    break;}
case 99:
#line 420 "cfg-grammar.y"
{ yyval.ptr = NULL; ;
    break;}
case 100:
#line 424 "cfg-grammar.y"
{ configuration->mark_freq = yyvsp[-1].num; ;
    break;}
case 101:
#line 425 "cfg-grammar.y"
{ configuration->sync_freq = yyvsp[-1].num; ;
    break;}
case 102:
#line 426 "cfg-grammar.y"
{ configuration->long_hostnames = yyvsp[-1].num; ;
    break;}
case 103:
#line 427 "cfg-grammar.y"
{ configuration->time_reopen = yyvsp[-1].num; ;
    break;}
case 104:
#line 428 "cfg-grammar.y"
{ configuration->log_fifo_size = yyvsp[-1].num; ;
    break;}
case 105:
#line 432 "cfg-grammar.y"
{ yyval.ptr = make_filter_rule(yyvsp[-4].cptr, yyvsp[-2].node); free(yyvsp[-4].cptr); ;
    break;}
case 106:
#line 436 "cfg-grammar.y"
{ yyval.node = yyvsp[0].node; if (!yyvsp[0].node) return 1; ;
    break;}
case 107:
#line 437 "cfg-grammar.y"
{ yyvsp[0].node->comp = !(yyvsp[0].node->comp); yyval.node = yyvsp[0].node; ;
    break;}
case 108:
#line 438 "cfg-grammar.y"
{ yyval.node = make_filter_or(yyvsp[-2].node, yyvsp[0].node); ;
    break;}
case 109:
#line 439 "cfg-grammar.y"
{ yyval.node = make_filter_and(yyvsp[-2].node, yyvsp[0].node); ;
    break;}
case 110:
#line 440 "cfg-grammar.y"
{ yyval.node = yyvsp[-1].node; ;
    break;}
case 111:
#line 444 "cfg-grammar.y"
{ yyval.node = make_filter_facility(yyvsp[-1].num);  ;
    break;}
case 112:
#line 445 "cfg-grammar.y"
{ yyval.node = make_filter_level(yyvsp[-1].num); ;
    break;}
case 113:
#line 446 "cfg-grammar.y"
{ yyval.node = make_filter_prog(yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 114:
#line 447 "cfg-grammar.y"
{ yyval.node = make_filter_host(yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 115:
#line 448 "cfg-grammar.y"
{ yyval.node = make_filter_match(yyvsp[-1].cptr); free(yyvsp[-1].cptr); ;
    break;}
case 116:
#line 452 "cfg-grammar.y"
{ yyval.num = yyvsp[-2].num + yyvsp[0].num; ;
    break;}
case 117:
#line 453 "cfg-grammar.y"
{ yyval.num = yyvsp[0].num; ;
    break;}
case 118:
#line 457 "cfg-grammar.y"
{ yyval.num = (1 << syslog_lookup_facility(yyvsp[0].cptr)); free(yyvsp[0].cptr); ;
    break;}
case 119:
#line 461 "cfg-grammar.y"
{ yyval.num = yyvsp[-2].num + yyvsp[0].num; ;
    break;}
case 120:
#line 462 "cfg-grammar.y"
{ yyval.num = yyvsp[0].num; ;
    break;}
case 121:
#line 466 "cfg-grammar.y"
{ yyval.num = (1 << syslog_lookup_level(yyvsp[0].cptr)); ;
    break;}
case 122:
#line 467 "cfg-grammar.y"
{ yyval.num = syslog_make_range(syslog_lookup_level(yyvsp[-2].cptr), syslog_lookup_level(yyvsp[0].cptr)); ;
    break;}
case 123:
#line 471 "cfg-grammar.y"
{ yyval.num = 1; ;
    break;}
case 124:
#line 472 "cfg-grammar.y"
{ yyval.num = 0; ;
    break;}
case 125:
#line 473 "cfg-grammar.y"
{ yyval.num = yyvsp[0].num; ;
    break;}
case 126:
#line 477 "cfg-grammar.y"
{ yyval.num = 2; ;
    break;}
case 127:
#line 478 "cfg-grammar.y"
{ yyval.num = 1; ;
    break;}
case 128:
#line 479 "cfg-grammar.y"
{ yyval.num = 0; ;
    break;}
}
   /* the action file gets copied in in place of this dollarsign */
#line 542 "/usr/share/misc/bison.simple"

  yyvsp -= yylen;
  yyssp -= yylen;
#ifdef YYLSP_NEEDED
  yylsp -= yylen;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

  *++yyvsp = yyval;

#ifdef YYLSP_NEEDED
  yylsp++;
  if (yylen == 0)
    {
      yylsp->first_line = yylloc.first_line;
      yylsp->first_column = yylloc.first_column;
      yylsp->last_line = (yylsp-1)->last_line;
      yylsp->last_column = (yylsp-1)->last_column;
      yylsp->text = 0;
    }
  else
    {
      yylsp->last_line = (yylsp+yylen-1)->last_line;
      yylsp->last_column = (yylsp+yylen-1)->last_column;
    }
#endif

  /* Now "shift" the result of the reduction.
     Determine what state that goes to,
     based on the state we popped back to
     and the rule number reduced by.  */

  yyn = yyr1[yyn];

  yystate = yypgoto[yyn - YYNTBASE] + *yyssp;
  if (yystate >= 0 && yystate <= YYLAST && yycheck[yystate] == *yyssp)
    yystate = yytable[yystate];
  else
    yystate = yydefgoto[yyn - YYNTBASE];

  goto yynewstate;

yyerrlab:   /* here on detecting error */

  if (! yyerrstatus)
    /* If not already recovering from an error, report this error.  */
    {
      ++yynerrs;

#ifdef YYERROR_VERBOSE
      yyn = yypact[yystate];

      if (yyn > YYFLAG && yyn < YYLAST)
	{
	  int size = 0;
	  char *msg;
	  int x, count;

	  count = 0;
	  /* Start X at -yyn if nec to avoid negative indexes in yycheck.  */
	  for (x = (yyn < 0 ? -yyn : 0);
	       x < (sizeof(yytname) / sizeof(char *)); x++)
	    if (yycheck[x + yyn] == x)
	      size += strlen(yytname[x]) + 15, count++;
	  msg = (char *) malloc(size + 15);
	  if (msg != 0)
	    {
	      strcpy(msg, "parse error");

	      if (count < 5)
		{
		  count = 0;
		  for (x = (yyn < 0 ? -yyn : 0);
		       x < (sizeof(yytname) / sizeof(char *)); x++)
		    if (yycheck[x + yyn] == x)
		      {
			strcat(msg, count == 0 ? ", expecting `" : " or `");
			strcat(msg, yytname[x]);
			strcat(msg, "'");
			count++;
		      }
		}
	      yyerror(msg);
	      free(msg);
	    }
	  else
	    yyerror ("parse error; also virtual memory exceeded");
	}
      else
#endif /* YYERROR_VERBOSE */
	yyerror("parse error");
    }

  goto yyerrlab1;
yyerrlab1:   /* here on error raised explicitly by an action */

  if (yyerrstatus == 3)
    {
      /* if just tried and failed to reuse lookahead token after an error, discard it.  */

      /* return failure if at end of input */
      if (yychar == YYEOF)
	YYABORT;

#if YYDEBUG != 0
      if (yydebug)
	fprintf(stderr, "Discarding token %d (%s).\n", yychar, yytname[yychar1]);
#endif

      yychar = YYEMPTY;
    }

  /* Else will try to reuse lookahead token
     after shifting the error token.  */

  yyerrstatus = 3;		/* Each real token shifted decrements this */

  goto yyerrhandle;

yyerrdefault:  /* current state does not do anything special for the error token. */

#if 0
  /* This is wrong; only states that explicitly want error tokens
     should shift them.  */
  yyn = yydefact[yystate];  /* If its default is to accept any token, ok.  Otherwise pop it.*/
  if (yyn) goto yydefault;
#endif

yyerrpop:   /* pop the current state because it cannot handle the error token */

  if (yyssp == yyss) YYABORT;
  yyvsp--;
  yystate = *--yyssp;
#ifdef YYLSP_NEEDED
  yylsp--;
#endif

#if YYDEBUG != 0
  if (yydebug)
    {
      short *ssp1 = yyss - 1;
      fprintf (stderr, "Error: state stack now");
      while (ssp1 != yyssp)
	fprintf (stderr, " %d", *++ssp1);
      fprintf (stderr, "\n");
    }
#endif

yyerrhandle:

  yyn = yypact[yystate];
  if (yyn == YYFLAG)
    goto yyerrdefault;

  yyn += YYTERROR;
  if (yyn < 0 || yyn > YYLAST || yycheck[yyn] != YYTERROR)
    goto yyerrdefault;

  yyn = yytable[yyn];
  if (yyn < 0)
    {
      if (yyn == YYFLAG)
	goto yyerrpop;
      yyn = -yyn;
      goto yyreduce;
    }
  else if (yyn == 0)
    goto yyerrpop;

  if (yyn == YYFINAL)
    YYACCEPT;

#if YYDEBUG != 0
  if (yydebug)
    fprintf(stderr, "Shifting error token, ");
#endif

  *++yyvsp = yylval;
#ifdef YYLSP_NEEDED
  *++yylsp = yylloc;
#endif

  yystate = yyn;
  goto yynewstate;

 yyacceptlab:
  /* YYACCEPT comes here.  */
  if (yyfree_stacks)
    {
      free (yyss);
      free (yyvs);
#ifdef YYLSP_NEEDED
      free (yyls);
#endif
    }
  return 0;

 yyabortlab:
  /* YYABORT comes here.  */
  if (yyfree_stacks)
    {
      free (yyss);
      free (yyvs);
#ifdef YYLSP_NEEDED
      free (yyls);
#endif
    }
  return 1;
}
#line 487 "cfg-grammar.y"


extern int linenum;

void yyerror(char *msg)
{
	fprintf(stderr, "%s at %d\n", msg, linenum);
}
